#
# @author Michele Van Dyne
# 11/10/16
# Class to represent a cave of rooms to explore
#
#
# Modified 11/1/2020
# Translated from Java to Python
#

import random
import Room

class Cave:

    #
    # Constructor for the cave class
    #  It creates an n x m cave filled with rooms and then populates each
    #  room with appropriate objects and conditions
    # @param int width, the width of the cave, in rooms
    # @param int height, the height, in rooms, of the cave
    #
    def __init__(self, width, height):
        # Create the rest of the attributes
        self.PITPROB = 0.2
        self.PIXELS = 100

        # Set up the 2D array of Rooms
        self.width = width
        self.height = height
        self.rooms = [[Room.Room() for i in range (height)] for j in range(width)]

        # Set the lower left corner as visited so that it appears lit
        self.rooms[0][0].setCondition(self.rooms[0][0].VISITED, True)
        
        # Place the wumpus
        wumpusPlaced = False
        while not wumpusPlaced:
            x = random.randint(0, width-1)
            y = random.randint(0, height-1)
            # He can't be in the first square
            if not(x == 0 and y == 0):
                self.rooms[x][y].setCondition(self.rooms[x][y].WUMPUS, True)
                wumpusPlaced = True
                # Mark the rooms around the wumpus as smelly
                self.markRoom(x, y, self.rooms[x][y].SMELLY, True)
        
        #Place the pits
        for i in range(0, width):
            for j in range(0, height):
                if random.random() < self.PITPROB and not(i == 0 and j == 0):
                    self.rooms[i][j].setCondition(self.rooms[i][j].PIT, True)
                    # Mark the rooms around pits as breezy
                    self.markRoom(i, j, self.rooms[i][j].BREEZY, True)
        
        # Place the gold
        x = random.randint(0, width-1)
        y = random.randint(0, height-1)
        self.rooms[x][y].setCondition(self.rooms[x][y].GLITTERY, True)

    #
    # Utility function that marks rooms around a feature (pit or wumpus)
    #  as breezy or smelly
    # @param int x, the x position of the room
    # @param int y, the y position of the room
    # @param Room.Conditions c, the condition to be marked
    # @param boolean b, whether to turn the condition on or off
    #
    def markRoom(self, x, y, c, b):
        if x-1 >= 0:
            self.rooms[x-1][y].setCondition(c, b)
        if x+1 < self.width:
            self.rooms[x+1][y].setCondition(c, b)
        if y-1 >= 0:
            self.rooms[x][y-1].setCondition(c, b)
        if y+1 < self.height:
            self.rooms[x][y+1].setCondition(c, b)
    
    #
    # Draws the entire cave by drawing each room separately
    #
    def draw(self):
        for x in range(0, self.width):
            for y in range(0, self.height):
                self.rooms[x][y].draw(self.PIXELS, x, y)

