#
# @author Michele Van Dyne
# 11/10/16
# Class describing the player in the Wumpus World game
#
#
# Modified 11/1/2020
# Translated from Java to Python
#

import StdDraw
import picture
from enum import Enum

class Direction(Enum):
    N = 0
    S = 1
    E = 2
    W = 3
 
class Player:

    def __init__(self):
        self.PIXELS = 100            # n x n pixels in the player image
        self.xLocation = 0           # current x position of the player
        self.yLocation = 0           # current y position of the player
        self.hasArrow = True         # whether the player still has its arrow
        self.image = picture.Picture("HeroTile.png")

    #
    # Public accessor for xLocation
    # @return int, the x position of the player
    #
    def getX(self):
        return self.xLocation

    #
    # Public accessor for yLocation
    # @return int, the y position of the player
    #
    def getY(self):
        return self.yLocation
    
    #
    # Public accessor for hasArrow
    # @return int, the y position of the player
    #
    def getArrow(self):
        return self.hasArrow
    
    #
    # Changes the player location based on the direction of movement
    # @param int height, the height of the cave
    # @param int width, the width of the cave
    # @param Direction d, the direction the player wishes to move
    # @return boolean, whether the move was successful or not
    #
    def move(self, height, width, d):
        if d == Direction.W and self.xLocation - 1 >= 0:
            self.xLocation -= 1
            return True
        if d == Direction.E and self.xLocation + 1 < width:
            self.xLocation += 1
            return True
        if d == Direction.S and self.yLocation - 1 >= 0:
            self.yLocation -= 1
            return True
        if d == Direction.N and self.yLocation + 1 < height:
            self.yLocation += 1
            return True
        return False

    #
    # Changes the value of hasArrow if player shoots it
    #
    def shootArrow(self):
        self.hasArrow = False

    #
    # Draws the player in the correct position in the cave
    # @param int i, the x position of the player
    # @param int j, the y position of the player
    #
    def draw(self):
        StdDraw.picture(self.image, (self.xLocation + 0.5) * self.PIXELS, (self.yLocation + 0.5) * self.PIXELS)

