#
# @author Michele Van Dyne
# 11/10/16
# Class describing a room in the Wumpus World cave
#
# Modified 11/1/2020
# Translated from Java to Python
#

import StdDraw
import picture

class Room:

    def __init__(self):
        # Setting up constants to serve as indices into an array of room characteristics
        self.SMELLY   = 0
        self.BREEZY   = 1
        self.GLITTERY = 2
        self.WUMPUS   = 3
        self.PIT      = 4
        self.VISITED  = 5

        # List of conditions for a room, indexed by the constants defined above
        self.conditions = [False, False, False, False, False, False]

        # Set up pictures for conditions
        self.visitedImage = picture.Picture("VisitedMapTile.png")
        self.pitImage = picture.Picture("PitTile.png")
        self.breezeImage = picture.Picture("BreezeTile.png")
        self.smellyImage = picture.Picture("StenchTile.png")
        self.wumpusImage = picture.Picture("WumpusTile.png")
        self.goldImage = picture.Picture("GoldTile.png")
        self.notVisitedImage = picture.Picture("NotVisitedMapTile.png")

    #
    # Public mutator for conditions
    # @param int c, the index of the condition to be changed
    # @param boolean b, the value to change the condition to
    #
    def setCondition(self, c, b):
        self.conditions[c] = b

    #
    # Public accessor for conditions
    # @param int index, the index of the condition to be returned
    # @return boolean, the value of the condition at the index
    #
    def getCondition(self, index):
        return self.conditions[index]

    #
    # Draws a room based on conditions and position in the cave
    # @param int pixels, the number of pixels defining the picture dimension
    # @param int x, the x location of the room
    # @param int y, the y location of the room
    #
    def draw(self, pixels, x, y):
        if (self.conditions[self.VISITED]):
            StdDraw.picture(self.visitedImage, (x + 0.5) * pixels, (y + 0.5) * pixels)
            if (self.conditions[self.PIT]):
                StdDraw.picture(self.pitImage, (x + 0.5) * pixels, (y + 0.5) * pixels)
            if (self.conditions[self.BREEZY]):
                StdDraw.picture(self.breezeImage, (x + 0.5) * pixels, (y + 0.5) * pixels)
            if (self.conditions[self.SMELLY]):
                StdDraw.picture(self.smellyImage, (x + 0.5) * pixels, (y + 0.5) * pixels)
            if (self.conditions[self.WUMPUS]):
                StdDraw.picture(self.wumpusImage, (x + 0.5) * pixels, (y + 0.5) * pixels)
            if (self.conditions[self.GLITTERY]):
                StdDraw.picture(self.goldImage, (x + 0.5) * pixels, (y + 0.5) * pixels)
        else:
            StdDraw.picture(self.notVisitedImage, (x + 0.5) * pixels, (y + 0.5) * pixels)

###
###   Code to test class Room
###
if __name__ == "__main__":
    #
    # Testing some valid values
    #

    # Create a room
    testRoom = Room()
    # Set some of its conditions to True
    testRoom.setCondition(testRoom.VISITED, True)
    testRoom.setCondition(testRoom.BREEZY, True)
    # Test to see that conditions are correct
    if testRoom.getCondition(testRoom.VISITED) == True:
        print("Passed VISITED set/get test")
    if testRoom.getCondition(testRoom.BREEZY) == True:
        print("Passed BREEZY set/get test")
    # Set up a 500x500 pixel (5x5 rooms) canvas to see if it draws correctly
    StdDraw.setCanvasSize(500, 500)
    StdDraw.setXscale(0, 500)
    StdDraw.setYscale(0, 500)
    # Draw the room in position 0, 0
    testRoom.draw(100, 0, 0)
    # Add a condition to the room
    testRoom.setCondition(testRoom.WUMPUS, True)
    if testRoom.getCondition(testRoom.WUMPUS) == True:
        print("Passed WUMPUS set/get test")
    # Draw the room at 1,1 and 4,4 
    testRoom.draw(100, 1, 1)
    testRoom.draw(100, 4, 4)
    StdDraw.show(3000)

    #
    # Testing some invalid conditions
    #

    testRoom.draw(100, 5,5)
    try:
        testRoom.setCondition(testRoom.WINDY, True)
    except:
        print("Invalid set condition not handled")

    testRoom.draw(50, 0, 4)
    StdDraw.show(3000)

