#
# @author Michele Van Dyne
# 11/10/16
# The game control class for the Wumpus World game
#
#
# Modified 11/1/2020
# Translated from Java to Python
#

import sys
import Room
import Cave
import Player
import StdDraw
import StdAudio

#
# Helper function to see if a fired arrow has hit the wumpus
# @param world the cave of rooms
# @param x     the integer x position
# @param y     the integer y position
#
# @return True if the arrow hit the wumpus, False otherwise
def checkWumpus(world, x, y):
    if world.rooms[x][y].getCondition(world.rooms[x][y].WUMPUS) == True:
        world.rooms[x][y].setCondition(world.rooms[x][y].WUMPUS, False)
        world.markRoom(x, y, world.rooms[x][y].SMELLY, False)
        print("You hear a horrible scream")
        StdAudio.playFile("scream_male")
        return True
    return False

# Helper variable for drawing
PIXELS = 100
# Flag to end game
done = False

# Generate world
width = int(sys.argv[1])
height = int(sys.argv[2])
world = Cave.Cave(width, height)

# Initialize the player
player = Player.Player()

# Prepare the standard draw window
StdDraw.setCanvasSize(width * PIXELS, height * PIXELS)
StdDraw.setXscale(0.0, PIXELS * width)  
StdDraw.setYscale(0.0, PIXELS * height)

# Start the game
while not done:
    StdDraw.clear()
    world.draw()
    player.draw()
    StdDraw.show(100)
    room = world.rooms[player.getX()][player.getY()]
    # Get user input for action
    if StdDraw.hasNextKeyTyped():
        action = StdDraw.nextKeyTyped()
        # If player shoots arrow (and still has the arrow)
        if (action == 'i' or action == 'j' or action == 'k' or action == 'l') and player.getArrow():
            player.shootArrow()
            StdAudio.playFile("arrow2")
            yPos = player.getY()
            xPos = player.getX()
            killedWumpus = False
            # Shoots north
            if action == 'i':
                while yPos < height and not killedWumpus:
                    # check for wumpus
                    killedWumpus = checkWumpus(world, xPos, yPos)
                    yPos += 1
            # Shoots west
            elif action == 'j' and not killedWumpus:
                while xPos >= 0:
                    # check for wumpus
                    killedWumpus = checkWumpus(world, xPos, yPos)
                    xPos -= 1
            # Shoots east
            elif action == 'l' and not killedWumpus:
                while xPos < width:
                    # check for wumpus
                    killedWumpus = checkWumpus(world, xPos, yPos)
                    xPos += 1
            # Shoots south
            elif action == 'k' and not killedWumpus:
                while yPos >= 0  and not killedWumpus:
                    # check for wumpus
                    killedWumpus = checkWumpus(world, xPos, yPos)
                    yPos -= 1
        # If player grabs the gold
        elif action == 'g':
            if room.getCondition(room.GLITTERY) == True:
                done = True
                print("Winner Winner, Chicken Dinner!!")
                StdAudio.playFile("cheering")
        # Player movement        
        # left
        elif action == 'a':
            if player.move(height, width, Player.Direction.W):
                room = world.rooms[player.getX()][player.getY()]
                room.setCondition(room.VISITED, True)
        # up
        elif action == 'w':
            if player.move(height, width, Player.Direction.N):
                room = world.rooms[player.getX()][player.getY()]
                room.setCondition(room.VISITED, True)
        # right
        elif action == 'd':
            if player.move(height, width, Player.Direction.E):
                room = world.rooms[player.getX()][player.getY()]
                room.setCondition(room.VISITED, True)
        # down
        elif action == 's':
            if player.move(height, width, Player.Direction.S):
                room = world.rooms[player.getX()][player.getY()]
                room.setCondition(room.VISITED, True)
    # Check for death
    if room.getCondition(room.WUMPUS) == True or room.getCondition(room.PIT) == True:
        done = True
        print("You have died a horrible death!!")
        if room.getCondition(room.WUMPUS) == True:
            StdAudio.playFile("burp2_x")
        else:
            StdAudio.playFile("crash_x")
    # Draw the cave
    # If game over, set all the rooms to be visible
    if done:
        for i in range(0, width):
            for j in range(0, height):
                world.rooms[i][j].setCondition(world.rooms[i][j].VISITED, True)
                
# Now draw everything again, one last time
StdDraw.clear()
world.draw()
player.draw()
StdDraw.show(3000)    

